@@ -33,6 +33,7 @@
 #include "CNSLPlugin.h"
 
 #define kAFPoverTCPServiceType	"afpovertcp"
+#define	kUseMachineName			"NSLUseMachineNameForRegistration"
 
 const CFStringRef	kLocalSAFE_CFSTR = CFSTR("local");
 const CFStringRef	kLocalDotSAFE_CFSTR = CFSTR("local.");
@@ -53,7 +54,7 @@ public:
 	virtual sInt32				SetServerIdleRunLoopRef	( CFRunLoopRef idleRunLoopRef );
 	virtual	void				ActivateSelf			( void );
 
-    virtual char*				CreateNSLTypeFromRecType( char *inRecType );
+    virtual char*				CreateNSLTypeFromRecType( char *inRecType, Boolean* needToFree );
 	virtual CFStringRef			CreateRecTypeFromNativeType ( char *inNativeType );
 
 			CFStringRef			GetComputerNameString	( void ) { return mComputerNameRef; }
@@ -85,6 +86,7 @@ private:
             DNSRegistrationThread* mRegistrationThread;
             CFMutableArrayRef	mListOfServicesToRegisterManually;
 			Boolean				mStartedNodeLookups;
+			Boolean				mStartedLocalNodeLookups;
 			Boolean				mRegisteredHostedServices;
 			CFStringRef			mComputerNameRef;
 			CFStringRef			mComputerMACAddressNameRef;
